@@ -164,6 +164,24 @@ class TestOLT(unittest.TestCase):
         self.assertEqual(len(ap_refs), 1)
         self.assertEqual(ap_refs.get('TestAP.100002'), exp_ref)
 
+    def test_olt_bootstrap_with_dot_in_id(self):
+        """PPA-1263 An OLT with a . in its source ID value works properly."""
+        # Create existing state (that will no longer be present)
+        cur_ref = NetworkMetadataReference(type='ap', value='Test.AP.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.TestAP', 'ap_config': 'Test.AP.100001', 'topology1_snmp': 'Test.AP', 'system': 'net'})
+        self._await(self.ctx.netmeta_model.set_ref(cur_ref))
+        olt = Olt(self.ctx, 'Test.AP', 'Test.AP', 'MySite', FakeClient('MyHost'), None, 'olt', None)
+        olt.module = FakeModule()
+        pon_port = olt.module.next_neu.data.interfaces.add()
+        pon = pon_port.pons.add()
+        pon.id = '100002'
+        pon.name = 'GPON 100002'
+        self._await(olt.load())
+        # old state should be removed and new state created
+        exp_ref = NetworkMetadataReference(type='ap', value='Test.AP.100002', attributes={'topology1': 'GPON 100002', 'topology2': 'OLT.Test.AP', 'ap_config': 'Test.AP.100002', 'topology1_snmp': 'Test.AP', 'system': 'net'})
+        ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
+        self.assertEqual(len(ap_refs), 1)
+        self.assertEqual(ap_refs.get('Test.AP.100002'), exp_ref)
+
     def setup_simple_network(self, bridged_macs=True, map_bh=False, map_ds_ap=False):
         """
         Setup messages and state to represent a simple network that has enough variety
@@ -530,3 +548,17 @@ class TestOLT(unittest.TestCase):
             '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
+
+    def test_linked_offline_ont(self):
+        """PPA-1529 do not map network metadata for linked offline ONTs."""
+        olt = self.setup_simple_network(bridged_macs=False)
+        olt.module.next_neu.peers[0].status = network_poller_pb2.ELEMENT_STATUS_OFFLINE
+
+        self.ctx.bridge_mapping_enabled = False
+        self.run_poll()
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 2)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
+        })
